#[non_exhaustive]pub enum SegmentationStrategy {
Lattice,
Eager,
}Expand description
Strategy used to segment hanja-containing spans.
Lattice considers every dictionary path and chooses the best coverage,
while Eager greedily takes the longest match at each cursor. The eager
strategy can reduce work for callers that prefer speed over segmentation
accuracy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Lattice
Use dynamic programming to maximize dictionary coverage.
Eager
Use left-to-right eager longest-match segmentation.